import { convertToLineNodes } from '.';
const decorationRegExp = /^(.*?)\[([!"#%&'()*+,-./{|}<>_~]+) ((?:\[[^\]]+\]|[^\]])+)\](.*)$/;
const createDecorationNode = (decoChars, nodes) => {
    const decoSet = new Set(decoChars);
    if (decoSet.has('*')) {
        const asteriskCount = decoChars.split('*').length - 1;
        decoSet.delete('*');
        decoSet.add(`*-${Math.min(asteriskCount, 10)}`);
    }
    return {
        type: 'decoration',
        decos: Array.from(decoSet),
        nodes
    };
};
export const DecorationNodeParser = (text, { nested, quoted }, next) => {
    if (nested)
        return next();
    const decorationMatch = text.match(decorationRegExp);
    if (!decorationMatch)
        return next();
    const [, left, decoChars, target, right] = decorationMatch;
    return [
        ...convertToLineNodes(left, { nested, quoted }),
        createDecorationNode(decoChars, convertToLineNodes(target, { nested: true, quoted })),
        ...convertToLineNodes(right, { nested, quoted })
    ];
};
//# sourceMappingURL=DecorationNode.js.map