"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UrlNodeParser = void 0;
const __1 = require("../");
const ExternalLinkNode_1 = require("./ExternalLinkNode");
const ImageNode_1 = require("./ImageNode");
const urlRegExp = /^(?<left>.*?)\[(?<href>https?:\/\/[^\s\]]+)(?<content>)\](?<right>.*)$/;
const leftUrlRegExp = /^(?<left>.*?)\[(?<href>https?:\/\/[^\s\]]+)\s+(?<content>[^\]]*[^\s])\](?<right>.*)$/;
const rightUrlRegExp = /^(?<left>.*?)\[(?<content>[^\]]*[^\s])\s+(?<href>https?:\/\/[^\s\]]+)\](?<right>.*)$/;
const httpRegExp = /^(?<left>.*?\s)?(?<href>https?:\/\/[^\s\]]+)(?<content>)(?<right>.*)$/;
const isUrlMatch = (obj) => (obj && obj.groups && obj.groups.href);
const isUrl = (text) => (/^https?:\/\/[^\s\]]+$/.test(text));
const isImageUrl = (text) => (/^https?:\/\/[^\s\]]+\.(png|jpe?g|gif|svg)(\?[^\]\s]+)?$/i.test(text) || isGyazoImageUrl(text));
const isGyazoImageUrl = (text) => (/^https?:\/\/([0-9a-z-]\.)?gyazo\.com\/[0-9a-f]{32}(\/raw)?$/.test(text));
const createUrlNode = (href, content) => {
    if (!(isUrl(content) && isImageUrl(content)) && !isImageUrl(href))
        return ExternalLinkNode_1.createExternalLinkNode(href, content);
    if (isImageUrl(content))
        [href, content] = [content, href];
    return ImageNode_1.createImageNode(href, content);
};
exports.UrlNodeParser = (text, { nested, quoted }, next) => {
    const UrlMatch = text.match(urlRegExp) ||
        text.match(leftUrlRegExp) ||
        text.match(rightUrlRegExp) ||
        text.match(httpRegExp);
    if (!isUrlMatch(UrlMatch))
        return next();
    const { left, href, content, right } = UrlMatch.groups;
    return [
        ...__1.convertToLineNodes(left, { nested, quoted }),
        createUrlNode(href, content),
        ...__1.convertToLineNodes(right, { nested, quoted })
    ];
};
//# sourceMappingURL=index.js.map